@@ -6,16 +6,18 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use crate::node_ops::MsgType;
 use crate::{
     chunk_store::BlobChunkStore,
     error::convert_to_error_message,
-    node_ops::{NodeDuties, NodeDuty, OutgoingMsg},
+    node_ops::{NodeDuty, OutgoingMsg},
     Error, Result,
 };
 use log::{error, info};
 use sn_data_types::{Blob, BlobAddress, DataAddress};
 use sn_messaging::{
-    client::{CmdError, Error as ErrorMessage, Message, NodeEvent, QueryResponse},
+    client::{CmdError, Error as ErrorMessage},
+    node::{NodeDataQueryResponse, NodeEvent, NodeMsg, NodeQueryResponse},
     Aggregation, DstLocation, EndUser, MessageId,
 };
 use std::{
@@ -42,15 +44,15 @@ impl ChunkStorage {
     pub(crate) async fn store(&mut self, data: &Blob, msg_id: MessageId) -> Result<NodeDuty> {
         let result = match self.try_store(data).await {
             Ok(()) | Err(Error::DataExists) => Ok(()), // if the data already exists we are fine too
-            Err(other) => Err(CmdError::Data(convert_to_error_message(other)?)),
+            Err(other) => Err(CmdError::Data(convert_to_error_message(other))),
         };
 
         Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::NodeEvent {
+            msg: MsgType::Node(NodeMsg::NodeEvent {
                 event: NodeEvent::ChunkWriteHandled(result),
                 id: MessageId::in_response_to(&msg_id),
                 correlation_id: msg_id,
-            },
+            }),
             section_source: false, // sent as single node
             // Data's metadata section
             dst: DstLocation::Section(*data.address().name()),
@@ -78,26 +80,21 @@ impl ChunkStorage {
         self.chunks.delete(&address).await
     }
 
-    pub(crate) fn get(&self, address: &BlobAddress, msg_id: MessageId) -> NodeDuties {
-        let mut ops = vec![];
+    pub(crate) fn get(&self, address: &BlobAddress, msg_id: MessageId) -> NodeDuty {
         let result = self
             .get_chunk(address)
             .map_err(|_| ErrorMessage::DataNotFound(DataAddress::Blob(*address)));
 
-        // Sent back to data's metadata section, who will then
-        // forward it to client after having recorded the adult liveness.
-        ops.push(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
+        NodeDuty::Send(OutgoingMsg {
+            msg: MsgType::Node(NodeMsg::NodeQueryResponse {
+                response: NodeQueryResponse::Data(NodeDataQueryResponse::GetChunk(result)),
                 id: MessageId::in_response_to(&msg_id),
-                response: QueryResponse::GetBlob(result),
                 correlation_id: msg_id,
-            },
+            }),
             section_source: false, // sent as single node
             dst: DstLocation::Section(*address.name()),
             aggregation: Aggregation::None,
-        }));
-
-        ops
+        })
     }
 
     /// Stores a chunk that Elders sent to it for replication.
@@ -155,11 +152,11 @@ impl ChunkStorage {
         };
 
         Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::NodeEvent {
+            msg: MsgType::Node(NodeMsg::NodeEvent {
                 event: NodeEvent::ChunkWriteHandled(result.map_err(CmdError::Data)),
                 id: MessageId::in_response_to(&msg_id),
                 correlation_id: msg_id,
-            },
+            }),
             section_source: false, // sent as single node
             // respond to data's metadata elders
             dst: DstLocation::Section(*address.name()),
