@@ -1,6 +1,6 @@
 use std::collections::BTreeSet;
 
-use sn_routing::XorName;
+use sn_routing::{Prefix, XorName};
 
 use crate::network::Network;
 
@@ -23,6 +23,11 @@ impl AdultReader {
         Self { network }
     }
 
+    /// Get the sections's current Prefix
+    pub async fn our_prefix(&self) -> Prefix {
+        self.network.our_prefix().await
+    }
+
     /// Dynamic state
     pub async fn non_full_adults_closest_to(
         &self,
